@@ -7,7 +7,7 @@ use Perl::Tidy;
 use Cwd;
 use File::Basename();
 
-our $VERSION = '0.17';
+our $VERSION = '0.18';
 
 our @mode;
 our $section;
@@ -291,7 +291,7 @@ sub _handle_text {
     $out .= sprintf '<sup><a href="#footnote_%s">%s</a></sup>', $text, $footnotes{$text};
   }elsif( $mode eq 'P' ){
     my ($year, $day, $label) = $text =~ m/^(\d{4})-(?:12-)?(\d{1,2})(?:\|(.+))?$/;
-    die "invalid date from P<$text>" unless $year =~ /^200[0-8]$/ && 1 <= $day && $day <= 25;
+    die "invalid date from P<$text>" unless $year && $year =~ /^200[0-9]$/ && 1 <= $day && $day <= 25;
     $out .= sprintf '<a href="../../%d/%d/">%s</a>',
 	$year, $day, ($label ? $label : sprintf '%d/%d', $year, $day);
 
@@ -372,7 +372,7 @@ Pod::Advent - POD Formatter for The Perl Advent Calendar
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =head1 GETTING STARTED
 
@@ -393,7 +393,7 @@ Using this module directly:
 
 Example POD:
 
-  =for advent_year 2008
+  =for advent_year 2009
 
   =for advent_day 32
 
@@ -494,7 +494,7 @@ Specify the author of the submission.
 
 Specify the year of the submission (defaults to current year).
 
-  =for advent_year 2008
+  =for advent_year 2009
 
 =head3 advent_day
 
